@@ -127,7 +127,7 @@ public:
    *     do_something();
    * @endcode
    */
-  inline operator bool() const;
+  inline explicit operator bool() const;
 
 #ifndef GLIBMM_DISABLE_DEPRECATED
   /// @deprecated Use reset() instead because this leads to confusion with clear() methods on the underlying class. For instance, people use .clear() when they mean ->clear().
@@ -169,10 +169,6 @@ public:
   template <class T_CastFrom>
   static inline RefPtr<T_CppObject> cast_const(const RefPtr<T_CastFrom>& src);
 
-  //TODO: Maybe remove these if we replace operator bool() with operator const void* after
-  //an API/ABI break, as suggested by Daniel Elstner? murrayc.
-  //See bug https://bugzilla.gnome.org/show_bug.cgi?id=626858
-
   /** Compare based on the underlying instance address.
    *
    * This is needed in code that requires an ordering on
@@ -212,7 +208,7 @@ T_CppObject* RefPtr<T_CppObject>::operator->() const
 template <class T_CppObject> inline
 RefPtr<T_CppObject>::RefPtr()
 :
-  pCppObject_ (0)
+  pCppObject_ (nullptr)
 {}
 
 template <class T_CppObject> inline
@@ -257,7 +253,7 @@ RefPtr<T_CppObject>::RefPtr(const RefPtr<T_CastFrom>& src)
 template <class T_CppObject> inline
 void RefPtr<T_CppObject>::swap(RefPtr<T_CppObject>& other)
 {
-  T_CppObject *const temp = pCppObject_;
+  const auto temp = pCppObject_;
   pCppObject_ = other.pCppObject_;
   other.pCppObject_ = temp;
 }
@@ -319,7 +315,7 @@ bool RefPtr<T_CppObject>::operator!=(const RefPtr<T_CppObject>& src) const
 template <class T_CppObject> inline
 RefPtr<T_CppObject>::operator bool() const
 {
-  return (pCppObject_ != 0);
+  return (pCppObject_ != nullptr);
 }
 
 #ifndef GLIBMM_DISABLE_DEPRECATED
@@ -342,7 +338,7 @@ template <class T_CppObject>
 inline
 RefPtr<T_CppObject> RefPtr<T_CppObject>::cast_dynamic(const RefPtr<T_CastFrom>& src)
 {
-  T_CppObject *const pCppObject = dynamic_cast<T_CppObject*>(src.operator->());
+  const auto pCppObject = dynamic_cast<T_CppObject*>(src.operator->());
 
   if(pCppObject)
     pCppObject->reference();
@@ -355,7 +351,7 @@ template <class T_CppObject>
 inline
 RefPtr<T_CppObject> RefPtr<T_CppObject>::cast_static(const RefPtr<T_CastFrom>& src)
 {
-  T_CppObject *const pCppObject = static_cast<T_CppObject*>(src.operator->());
+  const auto pCppObject = static_cast<T_CppObject*>(src.operator->());
 
   if(pCppObject)
     pCppObject->reference();
@@ -368,7 +364,7 @@ template <class T_CppObject>
 inline
 RefPtr<T_CppObject> RefPtr<T_CppObject>::cast_const(const RefPtr<T_CastFrom>& src)
 {
-  T_CppObject *const pCppObject = const_cast<T_CppObject*>(src.operator->());
+  const auto pCppObject = const_cast<T_CppObject*>(src.operator->());
 
   if(pCppObject)
     pCppObject->reference();
@@ -445,10 +441,10 @@ public:
   {
     result_stream << "new Test; ";
 #ifdef ACTIVATE_BUG //See https://bugzilla.gnome.org/show_bug.cgi?id=564005#c14
-    action->signal_sig1().connect(sigc::bind(sigc::mem_fun(this, &Test::on_sig1), action));
+    action->signal_sig1().connect(sigc::bind(sigc::mem_fun(*this, &Test::on_sig1), action));
 #else
     Glib::RefPtr<Action> action2(new Action);
-    action->signal_sig1().connect(sigc::bind(sigc::mem_fun(this, &Test::on_sig1), action2));
+    action->signal_sig1().connect(sigc::bind(sigc::mem_fun(*this, &Test::on_sig1), action2));
 #endif
   }
 
@@ -470,12 +466,12 @@ public:
 
 int main(int argc, char* argv[])
 {
-  TestUtilities* util = TestUtilities::get_instance();
+  auto util = TestUtilities::get_instance();
 
   if (!util->check_command_args(argc, argv))
     return util->get_result_and_delete_instance() ? EXIT_SUCCESS : EXIT_FAILURE;
 
-  Test* test = new Test;
+  auto test = new Test;
 
   test->action->emit_sig1(23);
   delete test;
